##########################################################################################

##  ADMINISTERING SECTION 2 AFTER SHELBY COUNTY
##  FIGURE 4 -- Negative Stereotypes

##########################################################################################

## Library in required packages
library(foreign)
library(arm)
library(weights)
library(zipcode)
library(maps)
library(mapproj)
library(RColorBrewer)
library(stringr)

## Set working directory
setwd('~/Dropbox/Papers/Elmendorf-Spencer/Data/section_2_replication/')

##########################################################################################

## CCAP data
x <- read.csv('data/ccap08-clean-with-vars.csv', stringsAsFactors=F)

## Census data for poststratification
census.white <- read.csv('data/poststratification/poststratification_2010_CVAP_county_WHITE.csv', stringsAsFactors=F)
census.black <- read.csv('data/poststratification/poststratification_2010_CVAP_county_BLACK.csv', stringsAsFactors=F)
census.hisp <- read.csv('data/poststratification/poststratification_2010_CVAP_county_HISPANIC.csv', stringsAsFactors=F)
census.asian <- read.csv('data/poststratification/poststratification_2010_CVAP_county_ASIAN.csv', stringsAsFactors=F)

##########################################################################################

## MERGE IN COUNTY DATA TO CCAP VIA ZIP CODE AREAS

## Zip-to-County data available via Missouri Census Data Center
mcdc <- read.csv('data/zip_to_county_equivalency.csv', stringsAsFactors=F)

mcdc$zipcode <- clean.zipcodes(mcdc$zcta5)
mcdc <- mcdc[!duplicated(mcdc$zipcode),] # Remove multiple entries

x$zipcode <- clean.zipcodes(x$zip)

x <- merge(x, mcdc, by='zipcode', all=F)

x$county.fips <- as.numeric(x$county02)

#census.names.all <- census.all[!duplicated(census.all$county.fips), -c(3:8)] # Missing fips c(4012,8014,35006,55078)
census.names.white <- census.white[!duplicated(census.white$county.fips), -c(3:8)]
census.names.black <- census.black[!duplicated(census.black$county.fips), -c(3:8)]
census.names.hisp <- census.hisp[!duplicated(census.hisp$county.fips), -c(3:8)]
census.names.asian <- census.asian[!duplicated(census.asian$county.fips), -c(3:8)]

## Change county names
x$polyname <- NULL # to avoid double-merge

##########################################################################################

## Add slave population in 1860 data
slave <- read.dta('data/updated_pslaveOConnell.dta', convert.underscore=T)
ccap <- merge(x, slave, by.x='county.fips', by.y='fips', all.x=T, all.y=F)
ccap$pslave[is.na(ccap$pslave)] <- 0

census.white <- merge(census.white, slave, by.x='county.fips', by.y='fips', all.x=T, all.y=F)
  census.white$pslave[is.na(census.white$pslave)] <- 0
census.black <- merge(census.black, slave, by.x='county.fips', by.y='fips', all.x=T, all.y=F)
  census.black$pslave[is.na(census.black$pslave)] <- 0
census.hisp <- merge(census.hisp, slave, by.x='county.fips', by.y='fips', all.x=T, all.y=F)
  census.hisp$pslave[is.na(census.hisp$pslave)] <- 0
census.asian <- merge(census.asian, slave, by.x='county.fips', by.y='fips', all.x=T, all.y=F)
  census.asian$pslave[is.na(census.asian$pslave)] <- 0

##########################################################################################

## Merge county names and subset by race
ccap.white <- merge(ccap[ccap$race=='White',], census.names.white[,-c(4,6,8)], by='county.fips', all=F)
ccap.black <- merge(ccap[ccap$race=='Black',], census.names.black[,-c(4,6,8)], by='county.fips', all=F)
ccap.hisp <- merge(ccap[ccap$race=='Hispanic',], census.names.hisp[,-c(4,6,8)], by='county.fips', all=F)
ccap.asian <- merge(ccap[ccap$race=='Asian',], census.names.asian[,-c(4,6,8)], by='county.fips', all=F)

## CREATE DEPENDENT VARIABLE

## Create own group stereotype variables
ccap.white$lazy.own <- ccap.white$lazy.white
ccap.black$lazy.own <- ccap.black$lazy.black
ccap.hisp$lazy.own <- ccap.hisp$lazy.hisp
ccap.asian$lazy.own <- ccap.asian$lazy.asian

ccap.white$intel.own <- ccap.white$intel.white
ccap.black$intel.own <- ccap.black$intel.black
ccap.hisp$intel.own <- ccap.hisp$intel.hisp
ccap.asian$intel.own <- ccap.asian$intel.asian

## Calculate the various different combinations of prejudice
# Lazy
ccap.white$black.L <- ccap.white$lazy.own - ccap.white$lazy.black
ccap.white$hisp.L <- ccap.white$lazy.own - ccap.white$lazy.hisp
ccap.white$asian.L <- ccap.white$lazy.own - ccap.white$lazy.asian
ccap.black$hisp.L <- ccap.black$lazy.own - ccap.black$lazy.hisp
ccap.black$asian.L <- ccap.black$lazy.own - ccap.black$lazy.asian
ccap.hisp$black.L <- ccap.hisp$lazy.own - ccap.hisp$lazy.black
ccap.hisp$asian.L <- ccap.hisp$lazy.own - ccap.hisp$lazy.asian
ccap.asian$black.L <- ccap.asian$lazy.own - ccap.asian$lazy.black
ccap.asian$hisp.L <- ccap.asian$lazy.own - ccap.asian$lazy.hisp

# Intelligence
ccap.white$black.I <- ccap.white$intel.own - ccap.white$intel.black
ccap.white$hisp.I <- ccap.white$intel.own - ccap.white$intel.hisp
ccap.white$asian.I <- ccap.white$intel.own - ccap.white$intel.asian
ccap.black$hisp.I <- ccap.black$intel.own - ccap.black$intel.hisp
ccap.black$asian.I <- ccap.black$intel.own - ccap.black$intel.asian
ccap.hisp$black.I <- ccap.hisp$intel.own - ccap.hisp$intel.black
ccap.hisp$asian.I <- ccap.hisp$intel.own - ccap.hisp$intel.asian
ccap.asian$black.I <- ccap.asian$intel.own - ccap.asian$intel.black
ccap.asian$hisp.I <- ccap.asian$intel.own - ccap.asian$intel.hisp

## Aggregate the differences
ccap.white$black.prejudice <- ccap.white$black.L + ccap.white$black.I
ccap.white$hisp.prejudice <- ccap.white$hisp.L + ccap.white$hisp.I
ccap.white$asian.prejudice <- ccap.white$asian.L + ccap.white$asian.I
ccap.black$hisp.prejudice <- ccap.black$hisp.L + ccap.black$hisp.I
ccap.black$asian.prejudice <- ccap.black$asian.L + ccap.black$asian.I
ccap.hisp$black.prejudice <- ccap.hisp$black.L + ccap.hisp$black.I
ccap.hisp$asian.prejudice <- ccap.hisp$asian.L + ccap.hisp$asian.I
ccap.asian$hisp.prejudice <- ccap.asian$hisp.L + ccap.asian$hisp.I
ccap.asian$black.prejudice <- ccap.asian$black.L + ccap.asian$black.I

## Normalize prejudice measure
ccap.white$prej.norm.black <- stdz(ccap.white$black.prejudice, weight=ccap.white$weight)
ccap.white$prej.norm.hisp <- stdz(ccap.white$hisp.prejudice, weight=ccap.white$weight)
ccap.white$prej.norm.asian <- stdz(ccap.white$asian.prejudice, weight=ccap.white$weight)

ccap.black$prej.norm.hisp <- stdz(ccap.black$hisp.prejudice, weight=ccap.black$weight)
ccap.black$prej.norm.asian <- stdz(ccap.black$asian.prejudice, weight=ccap.black$weight)

ccap.hisp$prej.norm.black <- stdz(ccap.hisp$black.prejudice, weight=ccap.hisp$weight)
ccap.hisp$prej.norm.asian <- stdz(ccap.hisp$asian.prejudice, weight=ccap.hisp$weight)

ccap.asian$prej.norm.black <- stdz(ccap.asian$hisp.prejudice, weight=ccap.asian$weight)
ccap.asian$prej.norm.hisp <- stdz(ccap.asian$hisp.prejudice, weight=ccap.asian$weight)

##########################################################################################

## INDEPENDENT VARIABLES

# Female dummy
ccap.white$female <- ifelse(ccap.white$sex=='Female', 1, 0)
ccap.black$female <- ifelse(ccap.black$sex=='Female', 1, 0)
ccap.hisp$female <- ifelse(ccap.hisp$sex=='Female', 1, 0)
ccap.asian$female <- ifelse(ccap.asian$sex=='Female', 1, 0)

census.white$female <- census.white$sex + 1
census.black$female <- census.black$sex + 1  
census.hisp$female <- census.hisp$sex + 1
census.asian$female <- census.asian$sex + 1

ccap.white$state.name <- tolower(ccap.white$state)
ccap.black$state.name <- tolower(ccap.black$state)
ccap.hisp$state.name <- tolower(ccap.hisp$state)
ccap.asian$state.name <- tolower(ccap.asian$state)

##########################################################################################

## MULTI-LEVEL MODELS

## Prejudice among whites
lm.white.black <- lmer(prej.norm.black ~ (1  | female) + (1 | educ) + (1 | polyname) + (1 | state.name) +
                         black.pct, data=ccap.white)
lm.white.hisp <- lmer(prej.norm.hisp ~ (1  | female) + (1 | educ) + (1 | polyname) + (1 | state.name) +
                         hisp.pct, data=ccap.white)
lm.white.asian <- lmer(prej.norm.asian ~ (1  | female) + (1 | educ) + (1 | polyname) + (1 | state.name) +
                         asian.pct, data=ccap.white)

## Prejudice among blacks
lm.black.hisp <- lmer(prej.norm.hisp ~ (1  | female) + (1 | educ) + (1 | polyname) + (1 | state.name) +
                        hisp.pct, data=ccap.black)
lm.black.asian <- lmer(prej.norm.asian ~ (1  | female) + (1 | educ) + (1 | polyname) + (1 | state.name) +
                         asian.pct, data=ccap.black)

## Prejudice among Latinos
lm.hisp.black <- lmer(prej.norm.black ~ (1  | female) + (1 | educ) + (1 | polyname) + (1 | state.name) +
                        black.pct, data=ccap.hisp)
lm.hisp.asian <- lmer(prej.norm.asian ~ (1  | female) + (1 | educ) + (1 | polyname) + (1 | state.name) +
                         asian.pct, data=ccap.hisp)

## Prejudice among asians
lm.asian.black <- lmer(prej.norm.black ~ (1  | female) + (1 | educ) + (1 | polyname) + (1 | state.name) +
                        black.pct, data=ccap.asian)
lm.asian.hisp <- lmer(prej.norm.hisp ~ (1  | female) + (1 | educ) + (1 | polyname) + (1 | state.name) +
                        hisp.pct, data=ccap.asian)

# Create vector of county ranefs and then fill in missing ones
county.name <- unique(as.character(census.names.white$polyname))
state.name <- unique(as.character(census.names.white$state.name))

ranefs.white.black <- array(NA,c(length(county.name),1))
  dimnames(ranefs.white.black) <- list(c(county.name), ('value'))
ranefs.white.black.S <- array(NA,c(length(state.name),1))
  dimnames(ranefs.white.black.S) <- list(c(state.name), ('value'))

ranefs.white.hisp <- array(NA,c(length(county.name),1))
  dimnames(ranefs.white.hisp) <- list(c(county.name), ('value'))
ranefs.white.hisp.S <- array(NA,c(length(state.name),1))
  dimnames(ranefs.white.hisp.S) <- list(c(state.name), ('value'))

ranefs.white.asian <- array(NA,c(length(county.name),1))
  dimnames(ranefs.white.asian) <- list(c(county.name), ('value'))
ranefs.white.asian.S <- array(NA,c(length(state.name),1))
  dimnames(ranefs.white.asian.S) <- list(c(state.name), ('value'))

ranefs.black.hisp <- array(NA,c(length(county.name),1))
  dimnames(ranefs.black.hisp) <- list(c(county.name), ('value'))
ranefs.black.hisp.S <- array(NA,c(length(state.name),1))
  dimnames(ranefs.black.hisp.S) <- list(c(state.name), ('value'))

ranefs.black.asian <- array(NA,c(length(county.name),1))
  dimnames(ranefs.black.asian) <- list(c(county.name), ('value'))
ranefs.black.asian.S <- array(NA,c(length(state.name),1))
  dimnames(ranefs.black.asian.S) <- list(c(state.name), ('value'))

ranefs.hisp.black <- array(NA,c(length(county.name),1))
  dimnames(ranefs.hisp.black) <- list(c(county.name), ('value'))
ranefs.hisp.black.S <- array(NA,c(length(state.name),1))
  dimnames(ranefs.hisp.black.S) <- list(c(state.name), ('value'))

ranefs.hisp.asian <- array(NA,c(length(county.name),1))
  dimnames(ranefs.hisp.asian) <- list(c(county.name), ('value'))
ranefs.hisp.asian.S <- array(NA,c(length(state.name),1))
  dimnames(ranefs.hisp.asian.S) <- list(c(state.name), ('value'))

ranefs.asian.black <- array(NA,c(length(county.name),1))
  dimnames(ranefs.asian.black) <- list(c(county.name), ('value'))
ranefs.asian.black.S <- array(NA,c(length(state.name),1))
  dimnames(ranefs.asian.black.S) <- list(c(state.name), ('value'))

ranefs.asian.hisp <- array(NA,c(length(county.name),1))
  dimnames(ranefs.asian.hisp) <- list(c(county.name), ('value'))
ranefs.asian.hisp.S <- array(NA,c(length(state.name),1))
  dimnames(ranefs.asian.hisp.S) <- list(c(state.name), ('value'))


for(j in county.name){
    ranefs.white.black[j,1] <- ranef(lm.white.black)$polyname[j,1]
    ranefs.white.hisp[j,1] <- ranef(lm.white.hisp)$polyname[j,1]
    ranefs.white.asian[j,1] <- ranef(lm.white.asian)$polyname[j,1]
    
    ranefs.black.hisp[j,1] <- ranef(lm.black.hisp)$polyname[j,1]
    ranefs.black.asian[j,1] <- ranef(lm.black.asian)$polyname[j,1]
    
    ranefs.hisp.black[j,1] <- ranef(lm.hisp.black)$polyname[j,1]
    ranefs.hisp.asian[j,1] <- ranef(lm.hisp.asian)$polyname[j,1]
    
    ranefs.asian.black[j,1] <- ranef(lm.asian.black)$polyname[j,1]
    ranefs.asian.hisp[j,1] <- ranef(lm.asian.hisp)$polyname[j,1]
}

ranefs.white.black[,1][is.na(ranefs.white.black[,1])] <- 0
ranefs.white.hisp[,1][is.na(ranefs.white.hisp[,1])] <- 0
ranefs.white.asian[,1][is.na(ranefs.white.asian[,1])] <- 0

ranefs.black.hisp[,1][is.na(ranefs.black.hisp[,1])] <- 0
ranefs.black.asian[,1][is.na(ranefs.black.asian[,1])] <- 0

ranefs.hisp.black[,1][is.na(ranefs.hisp.black[,1])] <- 0
ranefs.hisp.asian[,1][is.na(ranefs.hisp.asian[,1])] <- 0

ranefs.asian.black[,1][is.na(ranefs.asian.black[,1])] <- 0
ranefs.asian.hisp[,1][is.na(ranefs.asian.hisp[,1])] <- 0


for(k in state.name){
  ranefs.white.black.S[k,1] <- ranef(lm.white.black)$state.name[k,1]
  ranefs.white.hisp.S[k,1] <- ranef(lm.white.hisp)$state.name[k,1]
  ranefs.white.asian.S[k,1] <- ranef(lm.white.asian)$state.name[k,1]
  
  ranefs.black.hisp.S[k,1] <- ranef(lm.black.hisp)$state.name[k,1]
  ranefs.black.asian.S[k,1] <- ranef(lm.black.asian)$state.name[k,1]
  
  ranefs.hisp.black.S[k,1] <- ranef(lm.hisp.black)$state.name[k,1]
  ranefs.hisp.asian.S[k,1] <- ranef(lm.hisp.asian)$state.name[k,1]
  
  ranefs.asian.black.S[k,1] <- ranef(lm.asian.black)$state.name[k,1]
  ranefs.asian.hisp.S[k,1] <- ranef(lm.asian.hisp)$state.name[k,1]
}

ranefs.white.black.S[,1][is.na(ranefs.white.black.S[,1])] <- 0
ranefs.white.hisp.S[,1][is.na(ranefs.white.hisp.S[,1])] <- 0
ranefs.white.asian.S[,1][is.na(ranefs.white.asian.S[,1])] <- 0

ranefs.black.hisp.S[,1][is.na(ranefs.black.hisp.S[,1])] <- 0
ranefs.black.asian.S[,1][is.na(ranefs.black.asian.S[,1])] <- 0

ranefs.hisp.black.S[,1][is.na(ranefs.hisp.black.S[,1])] <- 0
ranefs.hisp.asian.S[,1][is.na(ranefs.hisp.asian.S[,1])] <- 0

ranefs.asian.black.S[,1][is.na(ranefs.asian.black.S[,1])] <- 0
ranefs.asian.hisp.S[,1][is.na(ranefs.asian.hisp.S[,1])] <- 0


## POSTSTRATIFICATION

## Create a prediction for each cell in Census data
cells.white.black <- (fixef(lm.white.black)['(Intercept)']
    + ranef(lm.white.black)$female[census.white$female,1]
    + ranef(lm.white.black)$educ[census.white$educ.cat,1]
    + ranefs.white.black[census.white$polyname,1]
    + ranefs.white.black.S[census.white$state.name,1]
    + (fixef(lm.white.black)['black.pct']*census.white$black.pct))
#    + (fixef(lm.white.black)['pslave']*census.white$pslave))

cells.white.hisp <- (fixef(lm.white.hisp)['(Intercept)']
    + ranef(lm.white.hisp)$female[census.white$female,1]
    + ranef(lm.white.hisp)$educ[census.white$educ.cat,1]
    + ranefs.white.hisp[census.white$polyname,1]
    + ranefs.white.hisp.S[census.white$state.name,1]
    + (fixef(lm.white.hisp)['hisp.pct']*census.white$hisp.pct))
#    + (fixef(lm.white.hisp)['pslave']*census.white$pslave))

cells.white.asian <- (fixef(lm.white.asian)['(Intercept)']
    + ranef(lm.white.asian)$female[census.white$female,1]
    + ranef(lm.white.asian)$educ[census.white$educ.cat,1]
    + ranefs.white.asian[census.white$polyname,1]
    + ranefs.white.asian.S[census.white$state.name,1]
    + (fixef(lm.white.asian)['asian.pct']*census.white$asian.pct))
#    + (fixef(lm.white.asian)['pslave']*census.white$pslave))

cells.black.hisp <- (fixef(lm.black.hisp)['(Intercept)']
    + ranef(lm.black.hisp)$female[census.black$female,1]
    + ranef(lm.black.hisp)$educ[census.black$educ.cat,1]
    + ranefs.black.hisp[census.black$polyname,1]
    + ranefs.black.hisp.S[census.black$state.name,1]
    + (fixef(lm.black.hisp)['hisp.pct']*census.black$hisp.pct))
#    + (fixef(lm.black.hisp)['pslave']*census.black$pslave))

cells.black.asian <- (fixef(lm.black.asian)['(Intercept)']
    + ranef(lm.black.asian)$female[census.black$female,1]
    + ranef(lm.black.asian)$educ[census.black$educ.cat,1]
    + ranefs.black.asian[census.black$polyname,1]
    + ranefs.black.asian.S[census.black$state.name,1]
    + (fixef(lm.black.asian)['asian.pct']*census.black$asian.pct))
#    + (fixef(lm.black.asian)['pslave']*census.asian$pslave))

cells.hisp.black <- (fixef(lm.hisp.black)['(Intercept)']
    + ranef(lm.hisp.black)$female[census.hisp$female,1]
    + ranef(lm.hisp.black)$educ[census.hisp$educ.cat,1]
    + ranefs.hisp.black[census.hisp$polyname,1]
    + ranefs.hisp.black.S[census.hisp$state.name,1]
    + (fixef(lm.hisp.black)['black.pct']*census.hisp$black.pct))
#    + (fixef(lm.hisp.black)['pslave']*census.hisp$pslave))

cells.hisp.asian <- (fixef(lm.hisp.asian)['(Intercept)']
    + ranef(lm.hisp.asian)$female[census.hisp$female,1]
    + ranef(lm.hisp.asian)$educ[census.hisp$educ.cat,1]
    + ranefs.hisp.asian[census.hisp$polyname,1]
    + ranefs.hisp.asian.S[census.hisp$state.name,1]
    + (fixef(lm.hisp.asian)['asian.pct']*census.hisp$asian.pct))
#    + (fixef(lm.hisp.asian)['pslave']*census.hisp$pslave))

cells.asian.black <- (fixef(lm.asian.black)['(Intercept)']
    + ranef(lm.asian.black)$female[census.asian$female,1]
    + ranef(lm.asian.black)$educ[census.asian$educ.cat,1]
    + ranefs.asian.black[census.asian$polyname,1]
    + ranefs.asian.black.S[census.asian$state.name,1]
    + (fixef(lm.asian.black)['black.pct']*census.asian$black.pct))
#    + (fixef(lm.asian.black)['pslave']*census.asian$pslave))

cells.asian.hisp <- (fixef(lm.asian.hisp)['(Intercept)']
    + ranef(lm.asian.hisp)$female[census.asian$female,1]
    + ranef(lm.asian.hisp)$educ[census.asian$educ.cat,1]
    + ranefs.asian.hisp[census.asian$polyname,1]
    + ranefs.asian.hisp.S[census.asian$state.name,1]
    + (fixef(lm.asian.hisp)['hisp.pct']*census.asian$hisp.pct))
#    + (fixef(lm.asian.hisp)['pslave']*census.asian$pslave))


## Weight the cell predictions by the cell frequency
weight.white.black <- cells.white.black * census.white$cell.percent
weight.white.hisp <- cells.white.hisp * census.white$cell.percent
weight.white.asian <- cells.white.asian * census.white$cell.percent

weight.black.hisp <- cells.black.hisp * census.black$cell.percent
weight.black.asian <- cells.black.asian * census.black$cell.percent

weight.hisp.black <- cells.hisp.black * census.hisp$cell.percent
weight.hisp.asian <- cells.hisp.asian * census.hisp$cell.percent

weight.asian.black <- cells.asian.black * census.asian$cell.percent
weight.asian.hisp <- cells.asian.hisp * census.asian$cell.percent


## Calculate state score and state proportions (i.e., weighted average of responses)
df <- data.frame(county.name=county.name,
    white.black=as.numeric(tapply(weight.white.black, census.white$polyname, sum)),
    white.hisp=as.numeric(tapply(weight.white.hisp, census.white$polyname, sum)),
    white.asian=as.numeric(tapply(weight.white.asian, census.white$polyname, sum)),
    black.hisp=as.numeric(tapply(weight.black.hisp, census.black$polyname, sum)),
    black.asian=as.numeric(tapply(weight.black.asian, census.black$polyname, sum)),
    hisp.black=as.numeric(tapply(weight.hisp.black, census.hisp$polyname, sum)),
    hisp.asian=as.numeric(tapply(weight.hisp.asian, census.hisp$polyname, sum)),
    asian.black=as.numeric(tapply(weight.asian.black, census.asian$polyname, sum)),
    asian.hisp=as.numeric(tapply(weight.asian.hisp, census.asian$polyname, sum))
)                  

## Aggregate stereotypes -- ** WEIGHTED SUM **
df$white.pct <- census.names.white$white.pct
df$black.pct <- census.names.white$black.pct
df$hisp.pct <- census.names.white$hisp.pct
df$asian.pct <- census.names.white$asian.pct

df$anti.black.sum <- (df$white.black*df$white.pct) + (df$hisp.black*df$hisp.pct) + (df$asian.black*df$black.pct)
df$anti.hisp.sum <- (df$white.hisp*df$white.pct) + (df$black.hisp*df$black.pct) + (df$asian.hisp*df$asian.pct)
df$anti.asian.sum <- (df$white.asian*df$white.pct) + (df$black.asian*df$black.pct) + (df$hisp.asian*df$hisp.pct)

## Cut negative stereotyping variable into distribution by SD
all.sd <- sd(rbind(df[,2], df[,3], df[,4], df[,5], df[,6], df[,7], df[,8], df[,9], df[,10])) # 0.03406866

census.all <- data.frame(rbind(census.white, census.black, census.hisp, census.asian))

census.all$black.prej <- c(cells.white.black, rep(NA,24600), cells.hisp.black, cells.asian.black)
census.all$hisp.prej <- c(cells.white.hisp, cells.black.hisp, rep(NA,24600), cells.asian.hisp)
census.all$asian.prej <- c(cells.white.asian, cells.black.asian, cells.hisp.asian, rep(NA,24600))

## Create national weight
nat.pop <- data.frame(polyname=unique(census.white$polyname),
                      white.pop=aggregate(county.freq~polyname, census.white, FUN=median)[,2],
                      black.pop=aggregate(county.freq~polyname, census.black, FUN=median)[,2],
                      hisp.pop=aggregate(county.freq~polyname, census.hisp, FUN=median)[,2],
                      asian.pop=aggregate(county.freq~polyname, census.asian, FUN=median)[,2])

census.all$nat.pop <- sum(nat.pop[,c(2:5)])
census.all$nat.weight <- census.all$nrow/census.all$nat.pop

nat <- census.all[sample(1:nrow(census.all), size=10000,
                         prob=census.all$nat.weight, replace=T),28:30]

new.sd <- sd(apply(nat, 1, function(x){sample(x[!is.na(x)], size = 1)})) # 0.1828338


df$colorBuckets.black <- cut(df$anti.black.sum,
                                 breaks=c(-1, 
                                          (median(df$anti.black.sum) - 2.5*all.sd),
                                          (median(df$anti.black.sum) - 1.5*all.sd),
                                          (median(df$anti.black.sum) - 0.5*all.sd),
                                          (median(df$anti.black.sum) + 0.5*all.sd),
                                          (median(df$anti.black.sum) + 1.5*all.sd),
                                          (median(df$anti.black.sum) + 2.5*all.sd), 1))

df$colorBuckets.hisp <- cut(df$anti.hisp.sum,
                                breaks=c(-1,
                                         (median(df$anti.hisp.sum) - 2.5*all.sd),
                                         (median(df$anti.hisp.sum) - 1.5*all.sd),
                                         (median(df$anti.hisp.sum) - 0.5*all.sd),
                                         (median(df$anti.hisp.sum) + 0.5*all.sd),
                                         (median(df$anti.hisp.sum) + 1.5*all.sd),
                                         (median(df$anti.hisp.sum) + 2.5*all.sd), 1))

df$colorBuckets.asian <- cut(df$anti.asian.sum,
                                 breaks=c(-1,
                                          (median(df$anti.asian.sum) - 2.5*all.sd),
                                          (median(df$anti.asian.sum) - 1.5*all.sd),
                                          (median(df$anti.asian.sum) - 0.5*all.sd),
                                          (median(df$anti.asian.sum) + 0.5*all.sd),
                                          (median(df$anti.asian.sum) + 1.5*all.sd),
                                          (median(df$anti.asian.sum) + 2.5*all.sd), 1))


levels(df$colorBuckets.black) <-
  levels(df$colorBuckets.hisp) <- 
  levels(df$colorBuckets.asian) <- c('-3', '-2', '-1', '0', '1', '2', '3')

##########################################################################################

## CREATE MAPS

data(county.fips)
county.fips <- county.fips[!duplicated(county.fips$fips),]
#county.fips <- county.fips[-(grep('south dakota,x', county.fips$polyname)),]

## Define colors (gray scale for printing)
colors <- c('gray90', 'gray75', 'gray60', 'gray50', 'gray35', 'gray20', 'black')

df.map <- merge(county.fips, df, by.x='polyname', by.y='county.name', all.x=F, all.y=T, sort=F)

## Set mapping projections
proj.type <- 'albers'
proj.stdlats <- c(29.5, 45.5)
proj.orient <- c(90,-100,0)

## Now the maps

pdf('figures/figure_3.pdf', width=30, height=20)
par(mar=c(2,2,2,1), mfrow=c(2,2))

## Black
map('county', col=colors[df.map$colorBuckets.black], fill=T, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=0, wrap=F, bound=T)
title('\n\nAnti black', cex.main=3.5)
map('state', col='white', fill=F, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=1, lwd=1.5, add=T)

## Latino
map('county', col=colors[df.map$colorBuckets.hisp], fill=T, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=0, wrap=F, bound=T)
title('\n\nAnti Latino', cex.main=3.5)
map('state', col='white', fill=F, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=1, lwd=1.5, add=T)

## Asian
map('county', col=colors[df.map$colorBuckets.asian], fill=T, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=0, wrap=F, bound=T)
title('\n\nAnti Asian', cex.main=3.5)
map('state', col='white', fill=F, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=1, lwd=1.5, add=T)

## Legend
diff.all <- rbind(df.map$anti.black.sum, df.map$anti.hisp.sum, df.map$anti.asian.sum)
df.dens <- density(stdz(diff.all))

plot(df.dens, axes=F, xlab='', ylab='', main='', type='n', xlim=c(-4,4), ylim=c(-0.3,1), cex.main=3.5)
text(0, 0.7, 'Distribution of negative stereotypes across counties\n(Legend)', cex=3)
axis(1, at=seq(-4,4,1), tick=F, labels=c('','','','','','','','',''), pos=0, lty=0)
axis(1, at=seq(-3,3,0.5), labels=c('-3','','-2','','-1','',"Nat'l avg.",'','1','','2','','3'), pos=0, cex.axis=2, padj=1, tick=F)
#abline(v=c(-2.5,-1.5,-.5,.5,1.5,2.5), col='lightgray')
text(0,-0.15,'Std. Dev.', cex=3)
text(-2.5, 0.2, 'Less negative', cex=2.5)
text(2.5, 0.2, 'More negative', cex=2.5)
polygon(x=c(seq(-4,-2.5,(1/51)), seq(-2.5,-4,-(1/51))),
        y=c(df.dens$y[df.dens$x > -4 & df.dens$x < -2.5], rep(0, 76)),
        col=colors[1], lty=0)
polygon(x=c(seq(-2.5,-1.5,(1/50)), seq(-1.5,-2.5,-(1/50))),
        y=c(df.dens$y[df.dens$x > -2.5 & df.dens$x < -1.5], rep(0, 51)),
        col=colors[2], lty=0)
polygon(x=c(seq(-1.5,-0.5,(1/51)), seq(-0.5,-1.5,-(1/50))),
        y=c(df.dens$y[df.dens$x > -1.5 & df.dens$x < -0.5], rep(0, 51)),
        col=colors[3], lty=0)
polygon(x=c(seq(-0.5, 0.5,(1/50)), seq(0.5,-0.5,-(1/50))),
        y=c(df.dens$y[df.dens$x > -0.5 & df.dens$x < 0.5], rep(0, 51)),
        col=colors[4], lty=0)
polygon(x=c(seq(0.5, 1.5,(1/51)), seq(1.5, 0.5,-(1/51))),
        y=c(df.dens$y[df.dens$x > 0.5 & df.dens$x < 1.5], rep(0, 52)),
        col=colors[5], lty=0)
polygon(x=c(seq(1.5, 2.5,(1/50)), seq(2.5, 1.5,-(1/50))),
        y=c(df.dens$y[df.dens$x > 1.5 & df.dens$x < 2.5], rep(0, 51)),
        col=colors[6], lty=0)
polygon(x=c(seq(2.5, 4,(1/51)), seq(4, 2.5,-(1/51))),
        y=c(df.dens$y[df.dens$x > 2.5 & df.dens$x < 4], rep(0, 76)),
        col=colors[7], lty=0)
#segments(x0=mean(stdz(diff.all)),
#         x1=mean(stdz(diff.all)),
#         y0=0, y1=0.6, lty=2)
dev.off()

############################################################
## For numbers describing Figure 3 (pp. 63-64 of version 7)

tx <- grep('texas,', df$county.name)
la <- grep('louisiana,', df$county.name)
ms <- grep('mississippi,', df$county.name)
al <- grep('alabama,', df$county.name)
ga <- grep('georgia,', df$county.name)
sc <- grep('south carolina,', df$county.name)
va <- grep('virginia', df$county.name)
s5 <- c(la,ms,al,ga,sc,va)

cat('\n\nCounties in Texas that score > 2 sd:',prop.table(table(ifelse(as.character(df$colorBuckets.black[tx]) >= 2, 1, 0)))[2],'
Counties formerly covered by s5 that score > 2sd:',prop.table(table(ifelse(as.character(df$colorBuckets.black[s5]) >= 2, 1, 0)))[2],
'\n\n')

par(mfrow=c(2,2))
plot(density(df$anti.black.sum, bw=0.001)); abline(v=mean(df$anti.black.sum))
plot(density(df$anti.hisp.sum, bw=0.001)); abline(v=mean(df$anti.hisp.sum))
plot(density(df$anti.asian.sum, bw=0.001)); abline(v=mean(df$anti.asian.sum))

par(mfrow=c(3,3))
plot(density(df$white.black, bw=0.001), main='White-Black'); abline(v=mean(df$white.black))
plot(density(df$white.hisp, bw=0.001), main='White-Latino'); abline(v=mean(df$white.hisp))
plot(density(df$white.asian, bw=0.001), main='White-Asian'); abline(v=mean(df$white.asian))
plot(density(df$black.hisp, bw=0.001), main='Black-Latino'); abline(v=mean(df$black.hisp))
plot(density(df$black.asian, bw=0.001), main='Black-Asian'); abline(v=mean(df$black.asian))
plot(density(df$hisp.black, bw=0.001), main='Latino-Black'); abline(v=mean(df$hisp.black))
plot(density(df$hisp.asian, bw=0.001), main='Latino-Asian'); abline(v=mean(df$hisp.asian))
plot(density(df$asian.black, bw=0.001), main='Asian-Black'); abline(v=mean(df$asian.black))
plot(density(df$asian.hisp, bw=0.001), main='Asian-Latino'); abline(v=mean(df$asian.hisp))

## Rank states by Anti-Asian stereotyping
df$state.name <- str_split_fixed(df$county.name, pattern=',', n=2)[,1]
state.asian <- data.frame(anti.asian=tapply(df$anti.asian.sum, df$state.name, sum))
state.asian$rank <- rank(state.asian$anti.asian)
state.asian[order(state.asian$rank),]



############################################################

head(df)

## Clear environment
rm(list=ls())

##########################################################################################
#  END OF FILE
##########################################################################################