############################################################

##  ADMINISTERING SECTION 2 AFTER SHELBY COUNTY
##  FIGURES 1 AND 2 -- Racially polarized ideology

############################################################

library(foreign)
library(ggplot2)
library(maps)
library(arm)
library(weights)

setwd('~/Dropbox/Papers/Elmendorf-Spencer/Data/section_2_replication/')

## READ IN DATA
cces <- read.csv('data/cces_all_with_ideal_points.csv', stringsAsFactors=F)

census.white <- read.csv('data/poststratification/poststratification_2010_CVAP_county_WHITE.csv', stringsAsFactors=F)
census.black <- read.csv('data/poststratification/poststratification_2010_CVAP_county_BLACK.csv', stringsAsFactors=F)
census.hisp <- read.csv('data/poststratification/poststratification_2010_CVAP_county_HISPANIC.csv', stringsAsFactors=F)
census.asian <- read.csv('data/poststratification/poststratification_2010_CVAP_county_ASIAN.csv', stringsAsFactors=F)

## Create non-white percent
census.white$nonwhite.pct <- (census.white$county.freq-census.white$white.pop)/census.white$county.freq
census.black$nonwhite.pct <- (census.black$county.freq-census.black$white.pop)/census.black$county.freq
census.hisp$nonwhite.pct <- (census.hisp$county.freq-census.hisp$white.pop)/census.hisp$county.freq
census.asian$nonwhite.pct <- (census.asian$county.freq-census.asian$white.pop)/census.asian$county.freq

# Subset to just four main races
x <- subset(cces, cces$race < 5 & cces$ideol.5 < 6); rm(cces)
x$race.name <- as.factor(x$race)
levels(x$race.name) <- c('White', 'Black', 'Latino', 'Asian')

x$educ.4 <- x$educ
x$educ.4[x$educ==4] <- 3
x$educ.4[x$educ==5 | x$educ==6] <- 4

x$female <- x$sex-1

#####

data(county.fips)
county.fips <- county.fips[!duplicated(county.fips$fips),] # remove duplicate entries
county <- merge(x, county.fips, by.x='county.code', by.y='fips', all.x=T)

census.names.white <- census.white[!duplicated(census.white$county.fips), -c(3:8)]
census.names.black <- census.black[!duplicated(census.black$county.fips), -c(3:8)]
census.names.hisp <- census.hisp[!duplicated(census.hisp$county.fips), -c(3:8)]
census.names.asian <- census.asian[!duplicated(census.asian$county.fips), -c(3:8)]

#####

## Add slave population in 1860 data
slave <- read.dta('data/updated_pslaveOConnell.dta', convert.underscore=T)
cces <- merge(county, slave, by.x='county.code', by.y='fips', all.x=T, all.y=F)
cces$pslave[is.na(cces$pslave)] <- 0

census.white <- merge(census.white, slave, by.x='county.fips', by.y='fips', all.x=T, all.y=F)
  census.white$pslave[is.na(census.white$pslave)] <- 0
census.black <- merge(census.black, slave, by.x='county.fips', by.y='fips', all.x=T, all.y=F)
  census.black$pslave[is.na(census.black$pslave)] <- 0
census.hisp <- merge(census.hisp, slave, by.x='county.fips', by.y='fips', all.x=T, all.y=F)
  census.hisp$pslave[is.na(census.hisp$pslave)] <- 0
census.asian <- merge(census.asian, slave, by.x='county.fips', by.y='fips', all.x=T, all.y=F)
  census.asian$pslave[is.na(census.asian$pslave)] <- 0

##########################################################################################

## Merge county names and subset by race
cces$state.name <- NULL # to prevent double merge
cces$polyname <- NULL

cces.white <- merge(cces[cces$race.name=='White',], census.names.white[,-c(4,6,8)],
                    by.x='county.code', by.y='county.fips', all=F)
cces.black <- merge(cces[cces$race.name=='Black',], census.names.black[,-c(4,6,8)],
                    by.x='county.code', by.y='county.fips', all=F)
cces.hisp <- merge(cces[cces$race.name=='Latino',], census.names.hisp[,-c(4,6,8)],
                   by.x='county.code', by.y='county.fips', all=F)
cces.asian <- merge(cces[cces$race.name=='Asian',], census.names.asian[,-c(4,6,8)],
                    by.x='county.code', by.y='county.fips', all=F)

census.white$female <- census.white$sex + 1
census.black$female <- census.black$sex + 1  
census.hisp$female <- census.hisp$sex + 1
census.asian$female <- census.asian$sex + 1

##########################################################################################

## MULTI-LEVEL MODELS

lm.ip.white <- lmer(ideal.mean ~ (1 | female) + (1 | educ.4) + (1 | polyname) + (1 | state.name) +
                      nonwhite.pct + pslave, data=cces.white)
lm.ip.black <- lmer(ideal.mean ~ (1 | female) + (1 | educ.4) + (1 | polyname) + (1 | state.name) +
                      nonwhite.pct + pslave, data=cces.black)
lm.ip.hisp <- lmer(ideal.mean ~ (1 | female) + (1 | educ.4) + (1 | polyname) + (1 | state.name) +
                     nonwhite.pct + pslave, data=cces.hisp)
lm.ip.asian <- lmer(ideal.mean ~ (1 | female) + (1 | educ.4) + (1 | polyname) + (1 | state.name) +
                      nonwhite.pct + pslave, data=cces.asian)

# Create vectors of state and county ranefs and then fill in missing ones
county.name <- unique(as.character(census.white$polyname))
state.name <- unique(as.character(census.white$state.name))

county.ranefs.white <- array(NA,c(length(county.name),1))
  dimnames(county.ranefs.white) <- list(c(county.name), c('value'))
state.ranefs.white <- array(NA,c(length(state.name),1))
  dimnames(state.ranefs.white) <- list(c(state.name), c('value'))

county.ranefs.black <- array(NA,c(length(county.name),1))
  dimnames(county.ranefs.black) <- list(c(county.name), c('value'))
state.ranefs.black <- array(NA,c(length(state.name),1))
  dimnames(state.ranefs.black) <- list(c(state.name), c('value'))

county.ranefs.hisp <- array(NA,c(length(county.name),1))
  dimnames(county.ranefs.hisp) <- list(c(county.name), c('value'))
state.ranefs.hisp <- array(NA,c(length(state.name),1))
  dimnames(state.ranefs.hisp) <- list(c(state.name), c('value'))

county.ranefs.asian <- array(NA,c(length(county.name),1))
  dimnames(county.ranefs.asian) <- list(c(county.name), c('value'))
state.ranefs.asian <- array(NA,c(length(state.name),1))
  dimnames(state.ranefs.asian) <- list(c(state.name), c('value'))

for(j in county.name){
  county.ranefs.white[j,1] <- ranef(lm.ip.white)$polyname[j,1]
  county.ranefs.black[j,1] <- ranef(lm.ip.black)$polyname[j,1]
  county.ranefs.hisp[j,1] <- ranef(lm.ip.hisp)$polyname[j,1]
  county.ranefs.asian[j,1] <- ranef(lm.ip.asian)$polyname[j,1]
}

county.ranefs.white[,1][is.na(county.ranefs.white[,1])] <- 0
county.ranefs.black[,1][is.na(county.ranefs.black[,1])] <- 0
county.ranefs.hisp[,1][is.na(county.ranefs.hisp[,1])] <- 0
county.ranefs.asian[,1][is.na(county.ranefs.asian[,1])] <- 0


for(k in state.name){
  state.ranefs.white[k,1] <- ranef(lm.ip.white)$state.name[k,1]
  state.ranefs.black[k,1] <- ranef(lm.ip.black)$state.name[k,1]
  state.ranefs.hisp[k,1] <- ranef(lm.ip.hisp)$state.name[k,1]
  state.ranefs.asian[k,1] <- ranef(lm.ip.asian)$state.name[k,1]
}

state.ranefs.white[,1][is.na(state.ranefs.white[,1])] <- 0
state.ranefs.black[,1][is.na(state.ranefs.black[,1])] <- 0
state.ranefs.hisp[,1][is.na(state.ranefs.hisp[,1])] <- 0
state.ranefs.asian[,1][is.na(state.ranefs.asian[,1])] <- 0


## POSTSTRATIFICATION

## Create a prediction for each cell in Census data
cells.white <- (fixef(lm.ip.white)['(Intercept)']
                + ranef(lm.ip.white)$female[census.white$female,1]
                + ranef(lm.ip.white)$educ.4[census.white$educ.cat,1]
                + county.ranefs.white[census.white$polyname,1]
                + state.ranefs.white[census.white$state.name,1]
                + (fixef(lm.ip.white)['nonwhite.pct']*census.white$nonwhite.pct)
                + (fixef(lm.ip.white)['pslave']*census.white$pslave))

cells.black <- (fixef(lm.ip.black)['(Intercept)']
                + ranef(lm.ip.black)$female[census.black$female,1]
                + ranef(lm.ip.black)$educ.4[census.black$educ.cat,1]
                + county.ranefs.black[census.black$polyname,1]
                + state.ranefs.black[census.black$state.name,1]
                + (fixef(lm.ip.black)['nonwhite.pct']*census.black$nonwhite.pct)
                + (fixef(lm.ip.black)['pslave']*census.black$pslave))

cells.hisp <- (fixef(lm.ip.hisp)['(Intercept)']
               + ranef(lm.ip.hisp)$female[census.hisp$female,1]
               + ranef(lm.ip.hisp)$educ[census.hisp$educ.cat,1]
               + county.ranefs.hisp[census.hisp$polyname,1]
               + state.ranefs.hisp[census.hisp$state.name,1]
               + (fixef(lm.ip.hisp)['nonwhite.pct']*census.hisp$nonwhite.pct)
               + (fixef(lm.ip.hisp)['pslave']*census.hisp$pslave))

cells.asian <- (fixef(lm.ip.asian)['(Intercept)']
                + ranef(lm.ip.asian)$female[census.asian$sex,1]
                + ranef(lm.ip.asian)$educ[census.asian$educ.cat,1]
                + county.ranefs.asian[census.asian$polyname,1]
                + state.ranefs.asian[census.asian$state.name,1]
                + (fixef(lm.ip.asian)['nonwhite.pct']*census.asian$nonwhite.pct)
                + (fixef(lm.ip.asian)['pslave']*census.asian$pslave))

weight.white <- cells.white * census.white$cell.percent
weight.black <- cells.black * census.black$cell.percent
weight.hisp <- cells.hisp * census.hisp$cell.percent
weight.asian <- cells.asian * census.asian$cell.percent

df <- data.frame(county.name=county.name,
                 white.ip=as.numeric(tapply(weight.white, census.white$polyname, sum)),
                 black.ip=as.numeric(tapply(weight.black, census.black$polyname, sum)),
                 hisp.ip=as.numeric(tapply(weight.hisp, census.hisp$polyname, sum)),
                 asian.ip=as.numeric(tapply(weight.asian, census.asian$polyname, sum))
)                  

## COMPARING IDEOLOGICAL DIFFERENCES AND DISPERSION BETWEEN RACES
## (original method commented out)

# Compare differences with respect to whites
  #df$black.diff <- abs(df$white.ip-df$black.ip)
  #df$hisp.diff <- abs(df$white.ip-df$hisp.ip)
  #df$asian.diff <- abs(df$white.ip-df$asian.ip)

  # Compare differences with respect to each other
  #df$black.hisp <- abs(df$black.ip-df$hisp.ip)
  #df$black.asian <- abs(df$black.ip-df$asian.ip)
  #df$hisp.asian <- abs(df$hisp.ip-df$asian.ip)

  # Standard deviation of all-group differences
  #diff.all <- c(df[,6], df[,7], df[,8], df[,9], df[,10], df[,11])
  #all.sd <- sd(diff.all)

## Estimate ideology by race in each county, weighted by frequency of 8 "types"

## First, add ideal points for each cell into the Census files

census.white$ideal.raw <- cells.white
census.black$ideal.raw <- cells.black
census.hisp$ideal.raw <- cells.hisp
census.asian$ideal.raw <- cells.asian

#census.white$ideal.weight <- weight.white
#census.black$ideal.weight <- weight.black
#census.hisp$ideal.weight <- weight.hisp
#census.asian$ideal.weight <- weight.asian

set.seed(1977)

N <- 3075

## Reset zero weights to positive number (otherwise sampling fails)
census.white$cell.percent[census.white$cell.percent==0] <- 0.000001
census.black$cell.percent[census.black$cell.percent==0] <- 0.000001
census.hisp$cell.percent[census.hisp$cell.percent==0] <- 0.000001
census.asian$cell.percent[census.asian$cell.percent==0] <- 0.000001

group.diff <- data.frame(row.names=unique(census.white$polyname),
       white.black=rep(NA,N), white.hisp=rep(NA,N), white.asian=rep(NA,N),
       black.hisp=rep(NA,N), black.asian=rep(NA,N), hisp.asian=rep(NA,N),
       white.white=rep(NA,N), black.black=rep(NA,N), hisp.hisp=rep(NA,N), asian.asian=rep(NA,N))

## Typical distance between-group differences
for (i in unique(census.white$polyname)){
  
  temp.white <- census.white[census.white$polyname==i,]
  temp.black <- census.black[census.black$polyname==i,]
  temp.hisp <- census.hisp[census.hisp$polyname==i,]
  temp.asian <- census.asian[census.asian$polyname==i,]
  
  temp.val.white.1 <- temp.white[sample(1:nrow(temp.white), size=10000,
                                      prob=temp.white$cell.percent, replace=T), 29]
  temp.val.white.2 <- temp.white[sample(1:nrow(temp.white), size=10000,
                                        prob=temp.white$cell.percent, replace=T), 29]
  
  temp.val.black.1 <- temp.black[sample(1:nrow(temp.black), size=10000, 
                                        prob=temp.black$cell.percent, replace=T), 29]
  temp.val.black.2 <- temp.black[sample(1:nrow(temp.black), size=10000, 
                                        prob=temp.black$cell.percent, replace=T), 29]
  
  temp.val.hisp.1 <- temp.hisp[sample(1:nrow(temp.hisp), size=10000, 
                                    prob=temp.hisp$cell.percent, replace=T), 29]
  temp.val.hisp.2 <- temp.hisp[sample(1:nrow(temp.hisp), size=10000, 
                                      prob=temp.hisp$cell.percent, replace=T), 29]
  
  temp.val.asian.1 <- temp.asian[sample(1:nrow(temp.asian), size=10000, 
                                      prob=temp.asian$cell.percent, replace=T), 29]
  temp.val.asian.2 <- temp.asian[sample(1:nrow(temp.asian), size=10000, 
                                        prob=temp.asian$cell.percent, replace=T), 29]
  
  group.diff[i,1] <- mean(abs(temp.val.white.1-temp.val.black.1))
  group.diff[i,2] <- mean(abs(temp.val.white.1-temp.val.hisp.1))
  group.diff[i,3] <- mean(abs(temp.val.white.1-temp.val.asian.1))
  group.diff[i,4] <- mean(abs(temp.val.black.1-temp.val.hisp.1))
  group.diff[i,5] <- mean(abs(temp.val.black.1-temp.val.asian.1))
  group.diff[i,6] <- mean(abs(temp.val.hisp.1-temp.val.asian.1))
  group.diff[i,7] <- mean(abs(temp.val.white.1-temp.val.white.2))
  group.diff[i,8] <- mean(abs(temp.val.black.1-temp.val.black.2))
  group.diff[i,9] <- mean(abs(temp.val.hisp.1-temp.val.hisp.2))
  group.diff[i,10] <- mean(abs(temp.val.asian.1-temp.val.asian.2))

  print(i)
}

## SD of national sample
census.all <- rbind(census.white, census.black, census.hisp, census.asian)
pop <- aggregate(nrow~polyname, data=census.all, FUN=sum)
census.all$weight.tot <- census.all$nrow/sum(pop$nrow)

rw <- aggregate(nrow~race.wha, data=census.all, FUN=sum)
census.all$race.weight <- NA
census.all$race.weight[census.all$race.wha==1] <- rw[1,2]/sum(rw$nrow)
census.all$race.weight[census.all$race.wha==2] <- rw[2,2]/sum(rw$nrow)
census.all$race.weight[census.all$race.wha==3] <- rw[3,2]/sum(rw$nrow)
census.all$race.weight[census.all$race.wha==4] <- rw[4,2]/sum(rw$nrow)

sd.sample.1 <- census.all[sample(1:nrow(census.all), size=10000, prob=census.all$race.weight, replace=T),]
sd.sample.2 <- census.all[sample(1:nrow(census.all), size=10000, prob=census.all$race.weight, replace=T),]

diff.all <- mean(abs(sd.sample.1$ideal.raw - sd.sample.2$ideal.raw))

###################################
## Check full sample:
prop.table(table(sd.sample.1$race.wha))
prop.table(table(sd.sample.2$race.wha))
# should be similar to...
table(census.all$race.weight)
###################################

## Now divide ideology by diff.all and note:
# 1 = group divergence is same as national divergence
# 0.5 = group divergence half national divergence
# 2 = group divergence double national divergence

group.diff$white.black.adj <- group.diff$white.black/diff.all
group.diff$white.hisp.adj <- group.diff$white.hisp/diff.all
group.diff$white.asian.adj <- group.diff$white.asian/diff.all
group.diff$black.hisp.adj <- group.diff$black.hisp/diff.all
group.diff$black.asian.adj <- group.diff$black.asian/diff.all
group.diff$hisp.asian.adj <- group.diff$hisp.asian/diff.all

group.diff$white.white.adj <- group.diff$white.white/diff.all
group.diff$black.black.adj <- group.diff$black.black/diff.all
group.diff$hisp.hisp.adj <- group.diff$hisp.hisp/diff.all
group.diff$asian.asian.adj <- group.diff$asian.asian/diff.all

## Create color buckets for mapping
group.diff$colorBuckets.black <- cut(group.diff$white.black.adj, breaks=c(0, 0.5, 1, 1.5, 2, 2.5, 3))
group.diff$colorBuckets.hisp <- cut(group.diff$white.hisp.adj, breaks=c(0, 0.5, 1, 1.5, 2, 2.5, 3))
group.diff$colorBuckets.asian <- cut(group.diff$white.asian.adj, breaks=c(0, 0.5, 1, 1.5, 2, 2.5, 3))
group.diff$colorBuckets.black.hisp <- cut(group.diff$black.hisp.adj, breaks=c(0, 0.5, 1, 1.5, 2, 2.5, 3))
group.diff$colorBuckets.black.asian <- cut(group.diff$black.asian.adj, breaks=c(0, 0.5, 1, 1.5, 2, 2.5, 3))
group.diff$colorBuckets.hisp.asian <- cut(group.diff$hisp.asian.adj, breaks=c(0, 0.5, 1, 1.5, 2, 2.5, 3))

group.diff$colorBuckets.white.white <- cut(group.diff$white.white.adj, breaks=c(0, 0.5, 1, 1.5, 2, 2.5, 3), include.lowest=T)
group.diff$colorBuckets.black.black <- cut(group.diff$black.black.adj, breaks=c(0, 0.5, 1, 1.5, 2, 2.5, 3), include.lowest=T)
group.diff$colorBuckets.hisp.hisp <- cut(group.diff$hisp.hisp.adj, breaks=c(0, 0.5, 1, 1.5, 2, 2.5, 3), include.lowest=T)
group.diff$colorBuckets.asian.asian <- cut(group.diff$asian.asian.adj, breaks=c(0, 0.5, 1, 1.5, 2, 2.5, 3), include.lowest=T)

## Merge in county names

data(county.fips)
county.fips <- county.fips[!duplicated(county.fips$fips),]
#county.fips <- county.fips[-(grep('south dakota,x', county.fips$polyname)),]

group.diff$polyname <- row.names(group.diff)
df.map <- merge(county.fips, group.diff, by='polyname', all.x=F, all.y=T, sort=F)

##  CREATE MAPS

## Define colors 
#colors <- c('gray95', 'gray85', 'gray75', 'gray60', 'gray40', 'black') # (gray scale for printing)
#colors <- c('#7FCDBB', '#C7E9B4', 'gray90', '#1D91C0', '#225EA8', '#0C2C84') # (Blue-Green)
#colors <- c('#006600', '#00CC33', '#FFFF66', '#FF0000', '#CC0000', '#990000') # (Stop light colors varying shades)
colors <- c('dodgerblue4', 'dodgerblue2', '#FFFF66', 'darkorange2', 'darkorange3', 'darkorange4')

## Set mapping projections
proj.type <- 'albers'
proj.stdlats <- c(29.5, 45.5)
proj.orient <- c(90,-100,0)

## FIGURE 1 -- Racially polarized ideology (with respect to whites)

pdf('figures/figure_1_color.pdf', width=30, height=20)
par(mar=c(0,0,0,1), mfrow=c(2,2))
map('county', col=colors[df.map$colorBuckets.black], fill=T, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=0, wrap=F, bound=T)
title('\n\nBlack vs. White', cex.main=3.5)
map('state', col='white', fill=F, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=1, lwd=1.5, add=T)

map('county', col=colors[df.map$colorBuckets.hisp], fill=T, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=0, wrap=F, bound=T)
title('\n\nLatino vs. White', cex.main=3.5)
map('state', col='white', fill=F, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=1, lwd=1.5, add=T)

map('county', col=colors[df.map$colorBuckets.asian], fill=T, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=0, wrap=F, bound=T)
title('\n\nAsian vs. White', cex.main=3.5)
map('state', col='white', fill=F, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=1, lwd=1.5, add=T)

## Legend
diff <- c(group.diff$white.hisp.adj, group.diff$white.black.adj, group.diff$white.asian.adj,
          group.diff$black.hisp.adj, group.diff$black.asian.adj, group.diff$hisp.asian.adj)
dens.diff <- density(diff, bw=0.15)

plot(dens.diff, axes=F, xlab='', ylab='', main='', type='n', xlim=c(-1,4), ylim=c(-0.3, 1.4), cex.main=3.5)
text(1, 1.1, 'Distribution of racially polarized ideology across counties\n(Legend)', cex=3)
axis(1, at=seq(-1,4,1), tick=F, labels=c('','','','','',''), pos=0, lty=0)
axis(1, at=seq(0,3,0.5), labels=c('0','0.5','1','1.5','2','2.5','3'), pos=0, cex.axis=2, padj=1, tick=F)
#abline(v=c(-2.5,-1.5,-.5,.5,1.5,2.5), col='lightgray')
#text(1.25,-0.15,'Ratio of between-group polarization to national polarization', cex=2.5)
text(-.5, 0.3, 'More cohesive', cex=2.5)
text(2.5, 0.3, 'More polarized', cex=2.5)
polygon(x=c(seq(0,0.5,(1/136)), seq(0.5,0,-(1/136))),
        y=c(dens.diff$y[dens.diff$x > 0 & dens.diff$x <= 0.5], rep(0, 69)),
        col=colors[1], lty=0) # White
polygon(x=c(seq(0.5,1,(1/138)), seq(1,0.5,-(1/138))),
        y=c(dens.diff$y[dens.diff$x > 0.5 & dens.diff$x <= 1], rep(0, 70)),
        col=colors[2], lty=0)
polygon(x=c(seq(1,1.5,(1/131)), seq(1.5,1,-(1/131))),
        y=c(dens.diff$y[dens.diff$x > 1 & dens.diff$x <= 1.5], rep(0, 62)),
        col=colors[3], lty=0)
polygon(x=c(seq(1.5, 2,(1/138)), seq(2,1.5,-(1/138))),
        y=c(dens.diff$y[dens.diff$x > 1.5 & dens.diff$x <= 2], rep(0, 71)),
        col=colors[4], lty=0)
polygon(x=c(seq(2, 2.5,(1/138)), seq(2.5, 2,-(1/138))),
        y=c(dens.diff$y[dens.diff$x > 2 & dens.diff$x <= 2.5], rep(0, 70)),
        col=colors[5], lty=0)
polygon(x=c(seq(2.5, 3,(1/131)), seq(3, 2.5,-(1/131))),
        y=c(dens.diff$y[dens.diff$x > 2.5 & dens.diff$x <= 3], rep(0, 62)),
        col=colors[6], lty=0)
dev.off()

############################################################
## For numbers describing Figure 1 (p. 62 of version 7)

tx <- grep('texas,', group.diff$polyname)
la <- grep('louisiana,', group.diff$polyname)
ms <- grep('mississippi,', group.diff$polyname)
al <- grep('alabama,', group.diff$polyname)
south <- c(tx,la,ms,al)

cat('\n\nCounties in country score > 1 in black vs. white:',prop.table(table(ifelse(group.diff$white.black.adj > 1, 1, 0)))[2],'
Counties in TX, LA, MS, and AL score > 2:',prop.table(table(ifelse(group.diff$white.black.adj[south] > 2, 1, 0)))[2],'
Texas counties > 1.5 for Latinos:',prop.table(table(ifelse(group.diff$white.hisp.adj[tx] > 1.5, 1, 0)))[2],'
Texas counties > 1.5 for Asians:  ',prop.table(table(ifelse(group.diff$white.asian.adj[tx] > 1.5, 1, 0)))[2],'\n\n')
############################################################

## FIGURE 2 -- Difference/similarity in ideal points between races

pdf('figures/figure_2_color.pdf', width=30, height=20)
par(mar=c(0,0,0,1), mfrow=c(2,2))
map('county', col=colors[df.map$colorBuckets.black.hisp], fill=T, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=0, wrap=F, bound=T)
title('\n\nBlack vs. Latino', cex.main=3.5)
map('state', col='white', fill=F, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=1, lwd=1.5, add=T)

map('county', col=colors[df.map$colorBuckets.black.asian], fill=T, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=0, wrap=F, bound=T)
title('\n\nBlack vs. Asian', cex.main=3.5)
map('state', col='white', fill=F, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=1, lwd=1.5, add=T)

map('county', col=colors[df.map$colorBuckets.hisp.asian], fill=T, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=0, wrap=F, bound=T)
title('\n\nLatino vs. Asian', cex.main=3.5)
map('state', col='white', fill=F, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=1, lwd=1.5, add=T)

## Legend
plot(dens.diff, axes=F, xlab='', ylab='', main='', type='n', xlim=c(-1,4), ylim=c(-0.3, 1.4), cex.main=3.5)
text(1, 1.1, 'Distribution of racially polarized ideology across counties\n(Legend)', cex=3)
axis(1, at=seq(-1,4,1), tick=F, labels=c('','','','','',''), pos=0, lty=0)
axis(1, at=seq(0,3,0.5), labels=c('0','0.5','1','1.5','2','2.5','3'), pos=0, cex.axis=2, padj=1, tick=F)
#abline(v=c(-2.5,-1.5,-.5,.5,1.5,2.5), col='lightgray')
#text(1.25,-0.15,'Ratio of between-group polarization to national polarization', cex=2.5)
text(-.5, 0.3, 'More cohesive', cex=2.5)
text(2.5, 0.3, 'More polarized', cex=2.5)
polygon(x=c(seq(0,0.5,(1/136)), seq(0.5,0,-(1/136))),
        y=c(dens.diff$y[dens.diff$x > 0 & dens.diff$x <= 0.5], rep(0, 69)),
        col=colors[1], lty=0) # White
polygon(x=c(seq(0.5,1,(1/138)), seq(1,0.5,-(1/138))),
        y=c(dens.diff$y[dens.diff$x > 0.5 & dens.diff$x <= 1], rep(0, 70)),
        col=colors[2], lty=0)
polygon(x=c(seq(1,1.5,(1/131)), seq(1.5,1,-(1/131))),
        y=c(dens.diff$y[dens.diff$x > 1 & dens.diff$x <= 1.5], rep(0, 62)),
        col=colors[3], lty=0)
polygon(x=c(seq(1.5, 2,(1/138)), seq(2,1.5,-(1/138))),
        y=c(dens.diff$y[dens.diff$x > 1.5 & dens.diff$x <= 2], rep(0, 71)),
        col=colors[4], lty=0)
polygon(x=c(seq(2, 2.5,(1/138)), seq(2.5, 2,-(1/138))),
        y=c(dens.diff$y[dens.diff$x > 2 & dens.diff$x <= 2.5], rep(0, 70)),
        col=colors[5], lty=0)
polygon(x=c(seq(2.5, 3,(1/131)), seq(3, 2.5,-(1/131))),
        y=c(dens.diff$y[dens.diff$x > 2.5 & dens.diff$x <= 3], rep(0, 62)),
        col=colors[6], lty=0)
dev.off()

############################################################
## For numbers describing Figure 2 (pp. 63-64 of version 7)

all.group <- c(group.diff$black.hisp.adj, group.diff$black.asian.adj, group.diff$hisp.asian.adj)

cat('\n\nCounties in all three minority groups that score < 1:',prop.table(table(ifelse(all.group < 1, 1, 0)))[2],'
Counties in Black-Latino that score < 0.5:',prop.table(table(ifelse(group.diff$black.hisp.adj < 0.5, 1, 0)))[2],'
Counties in Black-Asian that score < 0.5:',prop.table(table(ifelse(group.diff$black.asian.adj < 0.5, 1, 0)))[2],'
Counties in Latino-Asian that score < 0.5:',prop.table(table(ifelse(group.diff$hisp.asian.adj < 0.5, 1, 0)))[2],'\n\n')
############################################################

## FIGURE X -- Within group cohesion (not presented in paper)
#pdf('figures/figure_X_new.pdf', width=30, height=20)
par(mar=c(0,0,0,1), mfrow=c(2,2))
map('county', col=colors[df.map$colorBuckets.white.white], fill=T, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=0, wrap=F, bound=T)
title('\n\nWhite', cex.main=3.5)
map('state', col='white', fill=F, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=1, lwd=1.5, add=T)

map('county', col=colors[df.map$colorBuckets.black.black], fill=T, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=0, wrap=F, bound=T)
title('\n\nBlack', cex.main=3.5)
map('state', col='white', fill=F, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=1, lwd=1.5, add=T)

map('county', col=colors[df.map$colorBuckets.hisp.hisp], fill=T, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=0, wrap=F, bound=T)
title('\n\nLatino', cex.main=3.5)
map('state', col='white', fill=F, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=1, lwd=1.5, add=T)

map('county', col=colors[df.map$colorBuckets.asian.asian], fill=T, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=0, wrap=F, bound=T)
title('\n\nAsian', cex.main=3.5)
map('state', col='white', fill=F, proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, lty=1, lwd=1.5, add=T)

#dev.off()

################################################
################################################

## Density plots of between group differences (not presented in paper)
par(mfrow=c(2,3))
plot(density(group.diff$white.black.adj, bw=0.08), main='White vs. Black', xlab='')
abline(v=1)
plot(density(group.diff$white.hisp.adj, bw=0.08), main='White vs. Latino', xlab='')
abline(v=1)
plot(density(group.diff$white.asian.adj, bw=0.08), main='White vs. Asian', xlab='')
abline(v=1)
plot(density(group.diff$black.hisp.adj, bw=0.08), main='Black vs. Latino', xlab='')
abline(v=1)
plot(density(group.diff$black.asian.adj, bw=0.08), main='Black vs. Asian', xlab='')
abline(v=1)
plot(density(group.diff$hisp.asian.adj, bw=0.08), main='Latino vs. Asian', xlab='')
abline(v=1)

par(mfrow=c(2,2))
plot(density(group.diff$white.white.adj, bw=0.08), main='White vs. White', xlab='', xlim=c(0,1))
abline(v=c(1, mean(group.diff$white.white.adj)), lty=c(1,2))
plot(density(group.diff$black.black.adj, bw=0.08), main='Black vs. Black', xlab='', xlim=c(0,1))
abline(v=c(1, mean(group.diff$black.black.adj)), lty=c(1,2))
plot(density(group.diff$hisp.hisp.adj, bw=0.08), main='Latino vs. Latino', xlab='', xlim=c(0,1))
abline(v=c(1, mean(group.diff$hisp.hisp.adj)), lty=c(1,2))
plot(density(group.diff$asian.asian.adj, bw=0.08), main='Asian vs. Asian', xlab='', xlim=c(0,1))
abline(v=c(1, mean(group.diff$asian.asian.adj)), lty=c(1,2))

############################################################################################
############################################################################################
############################################################################################
############################################################################################
############################################################################################

## Create political knowledge dummy
#df$pol.know <- ifelse(df$party.control.H==1, 1, ifelse(df$party.control.S==2, 1, 0))
#df$pol.know.H <- ifelse(df$party.control.H==1, 1, 0)

#df1 <- x[!is.na(x$pol.know),]
#df2 <- x[!is.na(x$pol.know.H),]

## Density plots of ideal points

x <- read.csv('~/Dropbox/Papers/Elmendorf-Spencer/Data/section_2_replication/data/cces_all_with_ideal_points.csv', stringsAsFactors=F)
y <- x[x$party.3<4 & x$race<5,]

d <- ggplot(data=y, aes(x=ideal.mean, col=factor(y$party.3))) + 
  geom_density(adjust=3) + theme_bw() + xlab('') + ylab('') +
  scale_color_manual('Party', values=c('blue', 'red', 'green'), labels=c('Dem', 'Repub', 'Indep'))

#pdf('~/Dropbox/Papers/Elmendorf-Spencer/Writing : Slides/TeX/s2 Appendix/cces_ideal_density.pdf', height=3, width=5)
print(d)
#dev.off()


## Density plots of ideal points BY RACE

z <- subset(y, y$race < 5 & y$ideol.5 < 6)
z$race.name <- as.factor(z$race)
levels(z$race.name) <- c('White', 'Black', 'Latino', 'Asian')

z$ideal.norm <- stdz(z$ideal.mean)
z$ideol.norm <- stdz(z$ideol.5)

a <- data.frame(ideal=z$ideal.mean, race=z$race.name, party=z$party.3, type='Scaled measure')
b <- data.frame(ideal=z$ideol.norm, race=z$race.name, party=z$party.3, type='Self-reported')
c <- rbind(a, b)

race.plot.1 <- qplot(ideal, data=c, geom='density', adjust=3, col=type, facets=.~race) +
  theme_bw() + ylab('') + xlab('') + geom_vline(xintercept=0, linetype=2)

#pdf('~/Dropbox/Papers/Elmendorf-Spencer/Figures/ideol_by_race.pdf', height=4, width=8)
print(race.plot.1)
#dev.off()

race.plot.2 <- qplot(ideal, data=c, geom='density', adjust=5, col=as.factor(party), facets=type~race) +
  theme_bw() + ylab('') + xlab('Normalized ideology score') + #ggtitle('Ideology by Race') +
  scale_color_manual('Party', values=c('blue', 'red', 'green'), labels=c('Dem', 'Repub', 'Indep'))

#pdf('~/Dropbox/Papers/Elmendorf-Spencer/Writing : Slides/TeX/s2 Appendix/ideol_by_race_party.pdf', height=4.5, width=7.5)
print(race.plot.2)
#dev.off()


## And a few summary statistics
#We should calculate the pairwise correlation between IDEAL-derived ideology scores and
#  (a) self-reported partisanship
#  (b) self-reported ideology
#  (c) presidential vote, and 
#  (d) whether the respondent reported voting for the D or the R candidate for Congress

x.white <- subset(x, x$race.name=='White')
x.black <- subset(x, x$race.name=='Black')
x.hisp <- subset(x, x$race.name=='Latino')
x.asian <- subset(x, x$race.name=='Asian')

wh <- cor(x.white[,c(2,27,28,30)], use='complete.obs')
bl <- cor(x.black[,c(2,27,28,30)], use='complete.obs')
hi <- cor(x.hisp[,c(2,27,28,30)], use='complete.obs')
an <- cor(x.asian[,c(2,27,28,30)], use='complete.obs')

df.white.black <- cbind(wh,bl)
df.hisp.asian <- cbind(hi,an)

library(xtable)
xtable(df.white.black)
xtable(df.hisp.asian)
